/* O(N * M * log*N) */
#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <cassert>

using namespace std;

struct Interval {
    int x, y, weight;
};

istream& operator>>(istream& input, Interval& i) {
    input >> i.x >> i.y >> i.weight;
    --i.y;
    return input;
}

class DisjointSet {
  public:
    DisjointSet(int size):
        m_data(size, 0),
        m_anc(size, 0),
        m_before(size, 0),
        m_total(0) {
        for (int i = 0; i < size; ++i) {
            m_anc[i] = i;
            m_before[i] = i - 1;
        }
    }

    int anc(int x) {
        if (m_anc[x] == x)
            return x;
        return (m_anc[x] = anc(m_anc[x]));
    }

    void merge(int x, int y) {
        x = anc(x);
        y = anc(y);
        assert(anc(m_before[y]) == x);
        m_anc[y] = x;
        m_data[x] += m_data[y];
    }

    void increment(int x, int value) {
        m_data[anc(x)] += value;
        m_total += value;
    }

    int total() const {
        return m_total;
    }

    int value(int x) {
        return m_data[anc(x)];
    }

    bool check_merge(int x) {
        x = anc(x);
        if (m_before[x] == -1)
            return false;
        if (m_data[x] >= 0) {
            merge(m_before[x], x);
            return true;
        }
        return false;
    }

  private:
    vector<int> m_data, m_anc, m_before;
    int m_total = 0;
};

int main() {
    ifstream cin("popcorn.in");
    ofstream cout("popcorn.out");

    int M, N; assert(cin >> M >> N);
    assert(1 <= M && M <= 200000);
    assert(1 <= N && N <= M);

    vector<Interval> intervals(M);
    int max_coord = 0;
    for (int i = 0; i < M; ++i) {
        assert(cin >> intervals[i]);
        assert(1 <= intervals[i].x && intervals[i].x <= intervals[i].y && intervals[i].y <= 200000);
        max_coord = max(max_coord, intervals[i].y);
    }

    vector< vector< pair<int, int> > > ends_at(max_coord + 1);
    for (auto &interval: intervals)
        ends_at[interval.y].emplace_back(interval.x, interval.weight);

    vector<int> dp(max_coord + 1, 0);
    for (int picked = 1; picked <= N; ++picked) {
        // dp[i][j] = maximum weight sum you can get with exactly j points covering only intervals ending
        // up to coordinate j
        // dp[i][j] = max(dp[i - 1][k - 1] + t(k, j)) if we put a point at k
        //            for k from 1 to j
        //            where t(k, j) = sum of weight for intervals (a, b, w) where 
        //                      a <= k <= b <= j
        // our "data structure" must contain on position k dp[i - 1][k - 1] + t(k, j) for current j 
        DisjointSet D(max_coord + 1);

        vector<int> next_dp(max_coord + 1, 0);
        for (int j = 1; j <= max_coord; ++j) {
            D.increment(j, dp[j - 1] - D.total());
            while (D.check_merge(j));

            // first let's update with all intervals ending at j
            for (auto &interval : ends_at[j]) {
                int a = interval.first;
                int weight = interval.second;
                // so now (theoretically) we have to increment for all j = b >= k >= a, that is for all k in [a, b] with weight
                // so we increment only a's component
                D.increment(a, weight);

                // but now this component might be better than the previous
                while (D.check_merge(a));
            }

            next_dp[j] = D.value(0);
        }

        swap(dp, next_dp);
    }

    cout << dp[max_coord] << "\n";
}
